Page 131 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 131

Home

    While all of this was taking place, a massive
    propaganda campaign in the United States sought to
    deceive the American people into accepting a

    the

    deceive the American people into accepting a
    Communist takeover of China. An excellent source of

    into

    information about events during this time is John T.
    Flynn's book While You Slept: Our Tragedy In Asia and
    Who Made it. It was published by the Devin-Adair
    Company in 1951 and reprinted by Western Islands in
    1965.

    John T. Flynn was a graduate of Georgetown
    University, and had pursued a wide and varied career as
    a newspaper man being managing editor of the New
    York Globe, and a columnist for the New Republic and
    the Scripts- “Howard newspapers. The author of several

    books, and a radio commentator, John T. Flynn was
    known for his careful and responsible handling of facts.

    One thing that greatly puzzled Flynn was the way
    some of America's greatest newspapers, magazines,
    radio networks, and even motion picture producers
    supported the Communist takeover of China and

    supported the Communist takeover of China and
    slandered Chiang Kai-shek. Although many writers
    supporting Mao's communist guerrillas were later
    identified as Communists, the owners of the major news

    What writers like Flynn did not know was that these
    powerful and wealthy businessmen, operating out of
    New York, and working through the major tax-free
    foundations and organizations like the CFR, had

    126

    The Secret Side of History

    were later

    and entertainment media were certainly not Communists.

    foundations